==> qt6-qtwayland-6.5.2.tgz: lib/cmake/Qt6WlShellIntegrationPrivate/Qt6WlShellIntegrationPrivateAdditionalTargetInfo.cmake <==
# Additional target information for Qt6WlShellIntegrationPrivate
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::WlShellIntegrationPrivate)
get_target_property(_qt_imported_location Qt6::WlShellIntegrationPrivate IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_soname Qt6::WlShellIntegrationPrivate IMPORTED_SONAME_RELEASE)
get_target_property(_qt_imported_location_default Qt6::WlShellIntegrationPrivate IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_soname_default Qt6::WlShellIntegrationPrivate IMPORTED_SONAME_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::WlShellIntegrationPrivate" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::WlShellIntegrationPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_SONAME_RELWITHDEBINFO "${_qt_imported_soname}")
endif()

# Import target "Qt6::WlShellIntegrationPrivate" for configuration "MinSizeRel"
set_property(TARGET Qt6::WlShellIntegrationPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_SONAME_MINSIZEREL "${_qt_imported_soname}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()
if(_qt_imported_soname_default)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_SONAME "${_qt_imported_soname_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_configs)

==> qt6-qtwayland-6.8.3.tgz: lib/cmake/Qt6WlShellIntegrationPrivate/Qt6WlShellIntegrationPrivateAdditionalTargetInfo.cmake <==
# Additional target information for Qt6WlShellIntegrationPrivate
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::WlShellIntegrationPrivate)
get_target_property(_qt_imported_location Qt6::WlShellIntegrationPrivate IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_soname Qt6::WlShellIntegrationPrivate IMPORTED_SONAME_RELEASE)
get_target_property(_qt_imported_link_dependencies Qt6::WlShellIntegrationPrivate IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE)
get_target_property(_qt_imported_location_default Qt6::WlShellIntegrationPrivate IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_soname_default Qt6::WlShellIntegrationPrivate IMPORTED_SONAME_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_link_dependencies_default Qt6::WlShellIntegrationPrivate IMPORTED_LINK_DEPENDENT_LIBRARIES_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::WlShellIntegrationPrivate" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::WlShellIntegrationPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_SONAME_RELWITHDEBINFO "${_qt_imported_soname}")
endif()
if(_qt_imported_link_dependencies)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "${_qt_imported_link_dependencies}")
endif()

# Import target "Qt6::WlShellIntegrationPrivate" for configuration "MinSizeRel"
set_property(TARGET Qt6::WlShellIntegrationPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_SONAME_MINSIZEREL "${_qt_imported_soname}")
endif()
if(_qt_imported_link_dependencies)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LINK_DEPENDENT_LIBRARIES_MINSIZEREL "${_qt_imported_link_dependencies}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()
if(_qt_imported_soname_default)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_SONAME "${_qt_imported_soname_default}")
endif()
if(_qt_imported_link_dependencies_default)
    set_property(TARGET Qt6::WlShellIntegrationPrivate PROPERTY IMPORTED_LINK_DEPENDENT_LIBRARIES "${_qt_imported_link_dependencies_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_link_dependencies)
unset(_qt_imported_link_dependencies_default)
unset(_qt_imported_objects)
unset(_qt_imported_objects_default)
unset(_qt_imported_clr)
unset(_qt_imported_clr_default)
unset(_qt_imported_configs)
